@@ -1,6 +1,5 @@
 # noinspection PyUnresolvedReferences
-import uuid
-
+from uuid import uuid4, UUID
 from django.db import models
 
 # noinspection PyUnresolvedReferences
