@@ -7,7 +7,7 @@ class HltTap(BaseModel):
     """
 
     id = models.AutoField(db_column="TAPID", primary_key=True)
-    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid.uuid4)
+    uuid = models.CharField(db_column="UGUID", max_length=36, unique=True, default=uuid4)
     mkab = models.ForeignKey("HltMkab", models.DO_NOTHING, db_column="rf_MKABID", related_name="taps")
     katl = models.IntegerField(db_column="rf_KATLID", default=0)
     mkb = models.ForeignKey("OmsMkb", db_column="rf_MKBID", **FK_DEFAULT)
@@ -15,10 +15,10 @@ class HltTap(BaseModel):
     reason_care = models.ForeignKey("HltReasonCare", db_column="rf_ReasonCareID", **FK_DEFAULT)
     care_person_sex = models.BooleanField(db_column="CarePersonSex", default=0)
     care_person_age = models.IntegerField(db_column="CarePersonAge", default=0)
-    date_tap = models.DateTimeField(db_column="DateTAP", default=0)
+    date_tap = models.DateTimeField(db_column="DateTAP", default=timezone.now)
     inv = models.IntegerField(db_column="rf_INVID", default=0)
     not_work_doc_status = models.IntegerField(db_column="rf_NotWorkDocStatusID", default=0)
-    date_close = models.DateTimeField(db_column="DateClose", default=0)
+    date_close = models.DateTimeField(db_column="DateClose", default=timezone.now)
     lpu_doctor = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctorID", **FK_DEFAULT)
     lpu_doctor_s = models.ForeignKey("HltLpuDoctor", db_column="rf_LPUDoctor_SID", **FK_DEFAULT)
     smo = models.ForeignKey("OmsSmo", db_column="rf_SMOID", **FK_DEFAULT)
@@ -28,8 +28,8 @@ class HltTap(BaseModel):
     is_closed = models.BooleanField(db_column="IsClosed", default=0)
     is_worker = models.BooleanField(db_column="isWorker", default=0)
     spec_event_cert_id = models.IntegerField(db_column="rf_SpecEventCertID", default=0)
-    care_begin = models.DateTimeField(db_column="CareBegin", default=0)
-    care_end = models.DateTimeField(db_column="CareEnd", default=0)
+    care_begin = models.DateTimeField(db_column="CareBegin", default=timezone.now)
+    care_end = models.DateTimeField(db_column="CareEnd", default=timezone.now)
     family = models.CharField(db_column="FAMILY", max_length=40, default="")
     mkab_sheet_final_ds = models.IntegerField(db_column="rf_MKABSheetFinalDSID", default=0)
     direction_id = models.IntegerField(db_column="rf_DirectionID", default=0)
@@ -50,8 +50,8 @@ class HltTap(BaseModel):
     reason_type = models.ForeignKey("OmsKlReasonType", db_column="rf_kl_ReasonTypeID", **FK_DEFAULT)
     department = models.ForeignKey("OmsDepartment", db_column="rf_DepartmentID", **FK_DEFAULT)
     soc_status = models.ForeignKey("OmsKlSocStatus", db_column="rf_kl_SocStatusID", **FK_DEFAULT)
-    create_username = models.CharField(db_column="CreateUserName", max_length=255, default="")
-    edit_username = models.CharField(db_column="EditUserName", max_length=255, default="")
+    create_username = models.CharField(db_column="CreateUserName", max_length=255, default="не определено")
+    edit_username = models.CharField(db_column="EditUserName", max_length=255, default="не определено")
     flag_bill = models.BooleanField(db_column="FlagBill", default=0)
     flag_statist = models.BooleanField(db_column="FlagStatist", default=0)
     create_user = models.ForeignKey("XUser", db_column="rf_CreateUserID", **FK_DEFAULT)
@@ -61,8 +61,8 @@ class HltTap(BaseModel):
     type_tap_id = models.IntegerField(db_column="rf_TypeTAPID", default=0)
     registr_patient_id = models.IntegerField(db_column="rf_RegistrPatientID", default=0)
     doc_prvd = models.ForeignKey("HltDocPrvd", db_column="rf_DocPRVDID", **FK_DEFAULT)
-    mkp_card = models.UUIDField(db_column="rf_mkp_CardGUID", default=0)
-    date_create_tap = models.DateTimeField(db_column="DateCreateTAP", default=0)
+    mkp_card = models.UUIDField(db_column="rf_mkp_CardGUID", default=UUID('00000000-0000-0000-0000-000000000000'))
+    date_create_tap = models.DateTimeField(db_column="DateCreateTAP", default=timezone.now)
     num_in_other_system = models.CharField(db_column="NumInOtherSystem", max_length=50, default="")
     is_dvn_closed = models.BooleanField(db_column="isDVNClosed", default=0)
     med_care_type = models.ForeignKey("OmsKlMedCareType", db_column="rf_kl_MedCareTypeID", **FK_DEFAULT)
